# sack
Lightweight chat application for the terminal

<img width="1180" height="857" alt="image" src="https://github.com/user-attachments/assets/975a44b7-f1be-4cdb-a5da-9966364b1d9b" />

## About

sack is an open-source chat application for the terminal, built with the [Textual](https://github.com/Textualize/textual) framework and TCP sockets.  
Start your own server or join an existing one to chat within your local network.

## Installation

with [uv](https://github.com/astral-sh/uv):
```bash
uv tool install sack-chat
```

with pip:
```bash
pip install sack-chat
```

then you can run sack with `sack` command:
```bash
sack
```
